@@ -1,10 +1,11 @@
-from NewLifeUtils.ColorModule import ACC, MCC, FGC
-from NewLifeUtils.FileModule import create_files, get_yaml, file_exist, file_apwrite
-from NewLifeUtils.StringUtilModule import screate, remove_csi, parse_args
 import datetime
 import sys
 from msvcrt import getwch
 
+from NewLifeUtils.ColorModule import ACC, MCC, FGC
+from NewLifeUtils.FileModule import create_files, get_yaml, file_exist, file_apwrite
+from NewLifeUtils.StringUtilModule import screate, remove_csi, parse_args
+
 default_colors = """
 indianred:
   - 205
@@ -947,7 +948,7 @@ tag_length: 10
 colormap: 1
 
 file_log: true
-logtime: "%d-%m-%Y_%H-%M-%S"
+logtime: "%d-%m-%Y_%H-%M"
 logname: "log_{time}"
 """
 
@@ -976,6 +977,18 @@ colormap_type = settings_config["colormap"]
 colormap = {}
 
 
+
+
+if colormap_type == 2:
+    settings_color2 = get_yaml("logger_colors2", default_colors2)
+    for color in settings_color2:
+        h = settings_color2[color].lstrip("#")
+        colormap[color] = tuple(int(h[i : i + 2], 16) for i in (0, 2, 4))
+else:
+    settings_color1 = get_yaml("logger_colors", default_colors)
+    for color in settings_color1:
+        colormap[color] = ACC.customrgb(*settings_color1[color])
+
 def set_settings(
     new_log_pattern=log_pattern,
     new_wrn_pattern=wrn_pattern,
@@ -1028,18 +1041,6 @@ def set_settings(
     logtime = new_logtime
     logname = new_logname
 
-
-if colormap_type == 2:
-    settings_color2 = get_yaml("logger_colors2", default_colors2)
-    for color in settings_color2:
-        h = settings_color2[color].lstrip("#")
-        colormap[color] = tuple(int(h[i : i + 2], 16) for i in (0, 2, 4))
-else:
-    settings_color1 = get_yaml("logger_colors", default_colors)
-    for color in settings_color1:
-        colormap[color] = ACC.customrgb(*settings_color1[color])
-
-
 def tag_check(tag, default):
     if tag == "":
         return screate(default, tag_length)
@@ -1051,6 +1052,7 @@ def to_format(pattern, args):
     now = datetime.datetime.now()
 
     return (
+        ACC.RESET +
         pattern.format(
             **args,
             **colormap,
@@ -1070,8 +1072,7 @@ def out(text):
             )
 
         file_apwrite("log", remove_csi(text))
-
-    print(text)
+    sys.stdout.write(text+'\n')
 
 
 log = lambda message, tag="": out(
@@ -1102,7 +1103,8 @@ cstm = lambda pattern, args: out(to_format(pattern, args))
 
 rea = lambda message, tag="", completion=None: read(message, tag, completion)
 
-
+def get_read_formatting():
+    return ACC.bcustomrgb(0, 43, 112) + ACC.customrgb(235, 54, 30)
 def read(message, tag="", completion=None):
     if completion is None:
         completion = {}
@@ -1110,95 +1112,95 @@ def read(message, tag="", completion=None):
 
     current_text = ""
 
-    def complete(readed, completes):
-        nonlocal selector
-        nonlocal current_text
-        # print(f'{ACC.CLEARSCREEN}')
-        if current_text == "":
-            current_text = readed
-        work_parsed = parse_args(readed)["split"]
-        if readed != "":
-            if readed[-1] == " ":
-                work_parsed.append("")
+    # def complete(readed, completes):
+        # nonlocal selector
+        # nonlocal current_text
+        # # print(f'{ACC.CLEARSCREEN}')
+        # if current_text == "":
+            # current_text = readed
+        # work_parsed = parse_args(readed)["split"]
+        # if readed != "":
+            # if readed[-1] == " ":
+                # work_parsed.append("")
 
-        keys = completes.keys()
+        # keys = completes.keys()
 
-        # print(readed)
-        # print(current_text)
-        aval = []
-        if readed == "":
-            aval = list(completes.keys())
-        else:
-            for argnum, arg in enumerate(work_parsed, start=1):
-                aval = []
-                next_sel = False
-                for key in keys:
-                    # print(f'{FGC.GREEN}arg: {arg}, key: {key}, result: {key.startswith(arg)}')
-                    sys.stdout.flush()
-                    if key.startswith(arg):
-                        aval.append(key)
-                        next_sel = True
-                        try:
-                            completes[key]
-                        except KeyError:
-                            pass  # no completion next
-                            keys = {}
-                        else:
-                            sys.stdout.flush()
-                            keys = completes[key]
-                            next_sel = True
+        # # print(readed)
+        # # print(current_text)
+        # aval = []
+        # if readed == "":
+            # aval = list(completes.keys())
+        # else:
+            # for argnum, arg in enumerate(work_parsed, start=1):
+                # aval = []
+                # next_sel = False
+                # for key in keys:
+                    # # print(f'{FGC.GREEN}arg: {arg}, key: {key}, result: {key.startswith(arg)}')
+                    # sys.stdout.flush()
+                    # if key.startswith(arg):
+                        # aval.append(key)
+                        # next_sel = True
+                        # try:
+                            # completes[key]
+                        # except KeyError:
+                            # pass  # no completion next
+                            # keys = {}
+                        # else:
+                            # sys.stdout.flush()
+                            # keys = completes[key]
+                            # next_sel = True
 
-                if next_sel:
-                    selector += 1
-                    selector %= len(aval)
-                if len(aval) == 1:
-                    work_parsed[argnum - 1] = aval[0]
-                elif len(aval) > 0:
-                    work_parsed[argnum - 1] = aval[selector]
-                    # print(f'{FGC.MAGENTA}com: {aval}, next: {keys}, CURRENT: {selector} - {aval[selector]}')
+                # if next_sel:
+                    # selector += 1
+                    # selector %= len(aval)
+                # if len(aval) == 1:
+                    # work_parsed[argnum - 1] = aval[0]
+                # elif len(aval) > 0:
+                    # work_parsed[argnum - 1] = aval[selector]
+                    # # print(f'{FGC.MAGENTA}com: {aval}, next: {keys}, CURRENT: {selector} - {aval[selector]}')
 
-        # print(ACC.RESET)
+        # # print(ACC.RESET)
 
-        return " ".join(work_parsed), aval
+        # return " ".join(work_parsed), aval
 
-    def smart_input(text="", completes=None, end="\n"):
-        readed = ""
-        print(text + MCC.save_cursor, end="")
-        sys.stdout.flush()
-        while True:
-            key = getwch()
-            if ord(key) == 224:
-                pass
-            elif ord(key) == 0:
-                pass
-            else:
-                if ord(key) == 8:
-                    readed = readed[:-1]
-                    print(MCC.load_cursor + MCC.erase_nxt_line + readed, end="")
+    # def smart_input(text="", completes=None, end="\n"):
+        # readed = ""
+        # print(text + MCC.save_cursor, end="")
+        # sys.stdout.flush()
+        # while True:
+            # key = getwch()
+            # if ord(key) == 224:
+                # pass
+            # elif ord(key) == 0:
+                # pass
+            # else:
+                # if ord(key) == 8:
+                    # readed = readed[:-1]
+                    # print(MCC.load_cursor + MCC.erase_nxt_line + readed, end="")
 
-                elif ord(key) == 13:
-                    break
-                elif ord(key) == 9:
-                    readed, aval = complete(readed, completes)
-                    if len(aval) > 0:
-                        avalr = ", ".join(aval)
-                    else:
-                        avalr = "no suggestion"
-                    avaltext = f"{FGC.GRAY} ({avalr}) {ACC.RESET}"
-                    print(
-                        MCC.load_cursor
-                        + MCC.erase_nxt_line
-                        + readed
-                        + avaltext
-                        + MCC.left(len(remove_csi(avaltext))),
-                        end="",
-                    )
-                else:
-                    readed += key
-                    print(MCC.load_cursor + MCC.erase_nxt_line + readed, end="")
-            sys.stdout.flush()
-        print(end)
-        return readed
+                # elif ord(key) == 13:
+                    # break
+                # elif ord(key) == 9:
+                    # readed, aval = complete(readed, completes)
+                    # if len(aval) > 0:
+                        # avalr = ", ".join(aval)
+                    # else:
+                        # avalr = "no suggestion"
+                    # avaltext = f"{FGC.GRAY} ({avalr}) {ACC.RESET}"
+                    # print(
+                        # MCC.load_cursor
+                        # + MCC.erase_nxt_line
+                        # + readed
+                        # + avaltext
+                        # + MCC.left(len(remove_csi(avaltext))),
+                        # end="",
+                    # )
+                # else:
+                    # readed += key
+                    # print(MCC.load_cursor + MCC.erase_nxt_line + readed, end="")
+            # sys.stdout.flush()
+        # print(end)
+        # return readed
 
     if message[-1] not in [" ", ">", ":"]:
         message += ": "
@@ -1209,8 +1211,9 @@ def read(message, tag="", completion=None):
     readed = input()
 
     out(
-        MCC.up()
-        + ACC.RESET
+        ACC.RESET+
+        MCC.up(1)
+
         + MCC.ERASE_ALL_LINE
         + to_format(
             rea_pattern,
