@@ -2,6 +2,10 @@ import re
 
 
 def remove_csi(text):
+    """
+    Args:
+        text:
+    """
     return (
         re.sub(
             r"\\x1[bB]\[[\d;]*[a-zA-Z]",
@@ -14,6 +18,13 @@ def remove_csi(text):
 
 
 def screate(string, size=10, insert="r", filler_symbol=" "):
+    """
+    Args:
+        string:
+        size:
+        insert:
+        filler_symbol:
+    """
     calcstreeng = remove_csi(string)
 
     spaces = str(filler_symbol) * (size - len(calcstreeng))
@@ -24,21 +35,30 @@ def screate(string, size=10, insert="r", filler_symbol=" "):
 
 
 def sslice(text, chunk_size):
+    """
+    Args:
+        text:
+        chunk_size:
+    """
     text = str(text)
     return [text[i : i + chunk_size] for i in range(0, len(text), chunk_size)]
 
 
 def parse_args(readed):
-    # [\'][a-zA-ZА-Яа-я\d\s[\]{}()\\\.\":;,-]*[\']|\b[a-zA-Z\d]+
-    # [\"\'][a-zA-ZА-Яа-яЁё\d\s[\]{}()@\\\.:;,-]*[\"\']|[a-zA-ZA-ZА-Яа-яЁё\d\.[\]{}()@\\\.:;,-]+
-    # [\"][a-zA-ZА-Яа-яЁё\d\s[\]{}()@\\\.:;,\'-]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d\.[\]{}()@\\\.:;,\'-]+
-    # [\"][a-zA-ZА-Яа-яЁё\d\s[\]{}()@\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d\.[\]{}()@\\\.:;,\'-/]+
-    # [\"][a-zA-ZА-Яа-яЁё\d\s[\]{}()@#_=%?\*\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d\.[\]{}()@\\\.:;,\'-/]+
-    # [\"][a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+№\d]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+№]+
-    # [\"][a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+№\d]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+№<>]+ (NOW)
+    # [\'][a-zA-ZА-ЯЁа-яё\d\s[\]{}()\\\.\":;,-]*[\']|\b[a-zA-Z\d]+
+    # [\"\'][a-zA-ZА-ЯЁа-яё‘\d\s[\]{}()@\\\.:;,-]*[\"\']|[a-zA-ZA-ZА-ЯЁа-яё‘\d\.[\]{}()@\\\.:;,-]+
+    # [\"][a-zA-ZА-ЯЁа-яё‘\d\s[\]{}()@\\\.:;,\'-]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d\.[\]{}()@\\\.:;,\'-]+
+    # [\"][a-zA-ZА-ЯЁа-яё‘\d\s[\]{}()@\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d\.[\]{}()@\\\.:;,\'-/]+
+    # [\"][a-zA-ZА-ЯЁа-яё‘\d\s[\]{}()@#_=%?\*\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d\.[\]{}()@\\\.:;,\'-/]+
+    # [\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–]+
+    # [\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+ (NOW)
 
+    """
+    Args:
+        readed:
+    """
     res = re.findall(
-        r"[\"][a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+№\d]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+№<>]+",
+        r"[\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+",
         readed,
         re.MULTILINE,
     )
